import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"
import "./view"

import Artix.Handlers
import Artix.Core
import Artix.Gui

/**
 * @brief Диалог ввода текста
 */
FullscreenDialog {
    id: root

    padding: 24
    topPadding: 16

    property BasicTextField eventReceiver: inputField
    property DialogEventFilter eventFilter: DialogEventFilter {
        onKeyboardData: (data, rawData, source) => {
                            inputField.clear()
                            handler.input(data, rawData, source)
                        }
        onOk: accept()
        onCancel: reject()
    }

    contentItem: ColumnLayout {
        spacing: 24
        BasicLabel {
            objectName: "messageLabel"
            Style.class: "accessDialogMessage"
            Tr { tr: params.message }
        }
        BasicTextField {
            id: inputField
            objectName: "inputField"
            Layout.preferredWidth: 400
            Style.class: "inputDialogTextField"
            padding: 12
            echoMode: TextInput.Password
            Image {
                opacity: inputField.text.length > 0 ? 1 : 0
                anchors.right: parent.right
                anchors.rightMargin: 12
                anchors.verticalCenter: parent.verticalCenter
                width: 30
                height: 30
                source: Style.parameter("icon.textFieldClear")
                Component.onCompleted: mainWindow.scaleImage(this)
                MouseArea { anchors.fill: parent; onClicked: inputField.clear() }
                Behavior on opacity { NumberAnimation { duration: 250 } }
            }
        }
        Item { Layout.fillHeight: true }
    }

    PopupKeyboard {
        id: popupKeyboard
        keyboard {
            layoutType: "main"
            showCancel: true
            enterTr: Utils.makeTr("inputButton", "Ввод")
            onHide: inputField.focus = false
            onEnter: accept()
            onCancel: reject()
        }
        Connections {
            target: inputField
            function onFocusChanged() {
                if (inputField.focus)
                    popupKeyboard.open()
                else
                    popupKeyboard.close()
            }
        }
    }

    DialogHandler {
        id: handler
        allowDevices: params.allowDevices
    }

    function accept() {
        handler.sendAnswer(inputField.text, InputSource.Keyboard);
    }

    function reject() {
        handler.sendAnswer("", InputSource.Undefined)
    }

    Timer {
        interval: 50
        running: true
        onTriggered: {
            inputField.focus = true
        }
    }
}
