import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.VirtualKeyboard

import Artix.Gui
import Artix.Core
import Artix.Handlers

import "components"
import "view"

SideDialog {
    id: root
    padding: 24
    closePolicy: Popup.CloseOnPressOutside | Popup.CloseOnEscape
    implicitWidth: 392

    property var calcHandler: CalculateHandler {
        id: calcHandler
        inputReceiver: inputField

        onExpressionUpdated: () => {
            expressionField.text = expression;
        }
    }

    onClosed: {
        calcHandler.sendAnswer();
    }

    Component.onCompleted: {
        inputField.forceActiveFocus();
    }


    contentItem: ColumnLayout {
        height: 380
        width: 344
        spacing: 24

        BasicLabel {
            id: title
            Style.class: "calculateFormTitle"
            Layout.preferredHeight: 40
            Layout.fillWidth: true
            Tr {
                code: "calculateFormTitleLabel"
                defaultMessage: "Калькулятор"
            }
        }

        ColumnLayout {
            spacing: 24
            Layout.fillWidth: true
            Layout.preferredHeight: 480
            Layout.alignment: Qt.AlignTop | Qt.AlignHCenter

            GroupBox {
                Style.class: "calculateFormOutputField"
                Layout.preferredHeight: 84
                Layout.fillWidth: true
                Layout.alignment: Qt.AlignHCenter

                ColumnLayout {
                    spacing: 5
                    anchors.fill: parent
                    BasicLabel {
                        id: expressionField
                        Style.class: "calculateFormExpressionField"
                        rightPadding: 12
                        topPadding: 12
                        Layout.preferredHeight: 20
                        Layout.fillWidth: true
                        horizontalAlignment: Text.AlignRight
                        elide: Text.ElideLeft
                        wrapMode: Text.NoWrap
                    }
                    BasicTextField {
                        id: inputField
                        Style.class: "calculateFormInputField"
                        rightPadding: 12
                        Layout.preferredHeight: 40
                        Layout.fillWidth: true
                        hideCursor: true
                        horizontalAlignment: TextEdit.AlignRight
                        maximumLength: 15
                        validator: DoubleValidator {
                            decimals: 6
                            top: 9999999999999.0
                            notation: DoubleValidator.StandardNotation
                        }
                    }
                }
            }
            InlineKeyboard {
                id: keyboard
                Layout.preferredHeight: 372
                Layout.fillWidth: true
                layoutType: "math"
            }
        }

        BasicButton {
            Tr {
                code: "calculateFormCancelButton"
                defaultMessage: "Закрыть"
            }
            Layout.alignment: Qt.AlignBottom | Qt.AlignRight
            Layout.preferredHeight: 56
            Layout.preferredWidth: 200
            textLayout.alignment: Qt.AlignHCenter
            onClicked: close()
        }
    }
}
