import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"
import "view"

import Artix.Handlers
import Artix.Core
import Artix.Gui

/**
 * @brief Форма просмотра информации о сертификате.
 */
FullscreenDialog {
    readonly property var certificate: Utils.variantToObjectPointer(params.certificate)

    component InfoBox: GroupBox {
        Style.class: "certificateInfoCommonData"
        interactive: false
        leftPadding: 32
        topPadding: 24
        rightPadding: 32
        bottomPadding: 24
    }

    contentItem: RowLayout {
        spacing: 0
        Rectangle {
            Layout.fillWidth: true
            Layout.fillHeight: true
            color: Style.parameter("color.modalBackground")
            Flickable {
                anchors.fill: parent
                contentHeight: content.implicitHeight
                ColumnLayout {
                    id: content
                    anchors {
                        left: parent.left; right: parent.right; top: parent.top
                        leftMargin: 24; topMargin: 16; rightMargin: 24
                    }
                    spacing: 16
                    BasicLabel {
                        Style.class: "certificateInfoTitle"
                        Tr {
                            code: "certificateInfoFormTitle"
                            defaultMessage: "Информация о сертификате № %1"
                            args: [ certificate.number ]
                        }
                    }
                    Item { Layout.preferredHeight: 16 }
                    RowLayout {
                        spacing: 16
                        GroupBox {
                            id: balanceBox
                            Style.class: "certificateInfoMainData"
                            Layout.preferredWidth: 232
                            interactive: false
                            leftPadding: 32
                            rightPadding: 32
                            topPadding: 24
                            bottomPadding: 24
                            contentItem: ColumnLayout {
                                spacing: 4
                                BasicLabel {
                                    Style.class: "certificateInfoCommonLabel"
                                    Tr { code: "certificateInfoFormBalance"; defaultMessage: "Баланс" }
                                }
                                BasicLabel {
                                    Style.class: "certificateInfoBalanceValue"
                                    text: Utils.formatMoneyItem(certificate.balance)
                                }
                                Item { Layout.preferredHeight: 12 }
                                BasicLabel {
                                    Style.class: "certificateInfoCommonLabel"
                                    Tr { code: "certificateSpendType"; defaultMessage: "Тип погашения" }
                                }
                                BasicLabel {
                                    Style.class: "certificateInfoBalanceValue"
                                    Tr {
                                        tr: {
                                            if (certificate.fullySpend )
                                                return Utils.makeTr("certificateFullySpend", "Полное")
                                            else
                                                return Utils.makeTr("certificatePartialSpend", "Частичное")
                                        }
                                    }
                                }
                            }
                        }
                        InfoBox {
                            id: statusBox
                            Layout.fillWidth: true
                            Layout.preferredHeight: balanceBox.implicitHeight
                            contentItem: Item {
                                ColumnLayout {
                                    anchors { left: parent.left; right: parent.right; top: parent.top }
                                    spacing: 4
                                    BasicLabel {
                                        Style.class: "certificateInfoCommonLabel"
                                        Tr { code: "certificateInfoFormStatus"; defaultMessage: "Статус" }
                                    }
                                    BasicLabel {
                                        Style.class: certificate.isCanSpend ? "certificateInfoCanSpend"
                                                                            : "certificateInfoCantSpend"
                                        Layout.fillWidth: true
                                        text: certificate.status
                                    }
                                    // Здесь также предполагался срок действия сертификата, но таких данных у нас нет
                                }
                            }
                        }
                    }
                }
            }
        }
        Item {
            Layout.fillHeight: true
            Layout.preferredWidth: 304
            TopPanel {
                anchors { left: parent.left; top: parent.top; right: parent.right }
                anchors.leftMargin: 24
                hideUserName: true
            }
            ColumnLayout {
                anchors { left: parent.left; right: parent.right; bottom: parent.bottom; margins: 24 }
                spacing: 8
                BasicButton {
                    Style.class: "certificateInfoCancel"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 68
                    Tr { code: "certificateInfoFormCancel"; defaultMessage: "Закрыть" }
                    onClicked: handler.sendAnswer(false)
                }
            }
        }
    }

    DialogHandler { id: handler }
}
