import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Диалог выбора из двух вариантов
 */
ModalDialog {
    property DialogEventFilter eventFilter: DialogEventFilter {
        onOk: handler.sendAnswer(true)
        onCancel: handler.sendAnswer(false)
    }

    implicitWidth: image.visible ? Math.max(defaultWidth, image.width + leftPadding + rightPadding) : defaultWidth

    contentItem: ColumnLayout {
        spacing: 24
        ColumnLayout {
            spacing: 16
            Image {
                id: image
                Layout.alignment: Qt.AlignHCenter
                Layout.preferredHeight: 72
                Layout.maximumWidth: Style.resolution.width * 0.75
                fillMode: Image.PreserveAspectFit
                source: Style.parameter(params.image)
                Component.onCompleted: mainWindow.scaleImage(this)
            }

            BasicLabel {
                Layout.fillWidth: true
                Style.class: "choiceBoxMessage"
                horizontalAlignment: Text.AlignHCenter
                Tr { tr: params.message }
            }

            BasicLabel {
                Layout.fillWidth: true
                Style.class: "choiceBoxNote"
                horizontalAlignment: Text.AlignHCenter
                visible: text.length > 0
                Tr { tr: params.note }
            }
        }

        RowLayout {
            Layout.alignment: Qt.AlignHCenter
            spacing: 16
            BasicButton {
                objectName: "choiceBoxOkButton"
                Style.class: params.btnOkStyle
                Layout.preferredWidth: Style.layout.preferredWidth ? Style.layout.preferredWidth : 200
                Layout.preferredHeight: 56
                textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                Tr { tr: params.yesButton }
                onClicked: handler.sendAnswer(true)
            }
            BasicButton {
                objectName: "choiceBoxCancelButton"
                Style.class: params.btnCancelStyle
                Layout.preferredWidth: Style.layout.preferredWidth ? Style.layout.preferredWidth : 200
                Layout.preferredHeight: 56
                textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                Tr { tr: params.noButton }
                onClicked: handler.sendAnswer(false)
            }
        }
    }

    DialogHandler { id: handler }
}
