import QtQuick
import QtQuick.Layouts

import "components"
import "./view"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Диалог оплаты бонусами Manzana2019
 */
FullscreenDialog {
    id: root

    readonly property var cardRecord: Utils.variantToObjectPointer(params.card)
    readonly property var client: cardRecord?.card?.client
    readonly property var operationInfo: cardRecord.operationInfo

    property BasicTextField eventReceiver: inputField
    property DialogEventFilter eventFilter: DialogEventFilter {
        id: eventFilter
        onKeyboardData: (data, rawData, source) => {
                            inputField.clear()
                            handler.input(data, rawData, source)
                        }
        onOk: handler.ok(inputField.text, operationInfo["AvailablePayment"])
        onCancel: handler.cancel()
    }

    contentItem: RowLayout {
        // Левая часть
        Rectangle {
            Layout.fillWidth: true
            Layout.fillHeight: true
            color: Style.parameter("color.modalBackground")
            ColumnLayout {
                anchors {
                    top: parent.top; left: parent.left; right: parent.right
                    topMargin: 16; leftMargin: 24; rightMargin: 24
                }
                spacing: 48
                BasicLabel {
                    objectName: "manzanaLoyaltyInfoTitle"
                    Style.class: "manzanaLoyaltyInfoTitle"
                    Tr { code: "manzanaLoyaltyInfoFormTitle"; defaultMessage: "Система лояльности" }
                }
                ColumnLayout{
                    spacing: 16
                    Repeater {
                        id: manzanaLoyaltyInfoRepeater
                        property real maxWidth: 0
                        model: [
                            {
                                trCode: "manzanaLoyaltyInfoFormClientLabel", trDefaultMessage: "Клиент:",
                                value: client ? client.name : ""
                            },
                            {
                                trCode: "manzanaLoyaltyInfoFormSumLabel", trDefaultMessage: "Сумма:",
                                value: Utils.formatMoneyItem(operationInfo["Summ"])
                            },
                            {
                                trCode: "manzanaLoyaltyInfoFormSumWithDiscountLabel", trDefaultMessage: "Сумма со скидкой:",
                                value: Utils.formatMoneyItem(operationInfo["SummDiscounted"])
                            },
                            {
                                trCode: "manzanaLoyaltyInfoFormBonusBalanceLabel", trDefaultMessage: "Баланс ЯР:",
                                value: Utils.formatMoneyItem(operationInfo["CardNormalActiveBalance"])
                            },
                            {
                                trCode: "manzanaLoyaltyInfoFormBonusChipsBalanceLabel", trDefaultMessage: "Баланс фишек:",
                                value: Utils.formatMoneyItem(operationInfo["CardStatusActiveBalance"])
                            },
                            {
                                trCode: "manzanaLoyaltyInfoFormWriteOffBonusLabel", trDefaultMessage: "Списано ЯР:",
                                value: Utils.formatMoneyItem(parseFloat(operationInfo["WriteOffBonus"]) - parseFloat(operationInfo["WriteOffStatusBonus"]))
                            },
                            {
                                trCode: "manzanaLoyaltyInfoFormWriteOffBonusChipsLabel", trDefaultMessage: "Списано фишек:",
                                value: Utils.formatMoneyItem(operationInfo["WriteOffStatusBonus"])
                            },
                            {
                                trCode: "manzanaLoyaltyInfoFormEarnBonusLabel", trDefaultMessage: "Начислено ЯР:",
                                value: Utils.formatMoneyItem(parseFloat(operationInfo["ChargedBonus"]) - parseFloat(operationInfo["ChargedStatusBonus"]))
                            },
                            {
                                trCode: "manzanaLoyaltyInfoFormEarnBonusChipsLabel", trDefaultMessage: "Начислено фишек:",
                                value: Utils.formatMoneyItem(operationInfo["ChargedStatusBonus"])
                            },
                            {
                                trCode: "manzanaLoyaltyInfoFormAvailablePaymentLabel", trDefaultMessage: "Доступно для оплаты:",
                                value: Utils.formatMoneyItem(operationInfo["AvailablePayment"])
                            }
                        ]
                        delegate: RowLayout {
                            spacing: 24
                            BasicLabel {
                                objectName: "manzanaLoyaltyInfoListElementName"
                                Style.class: "manzanaLoyaltyInfoLabel"
                                Tr { code: modelData.trCode; defaultMessage: modelData.trDefaultMessage }
                                Layout.preferredWidth: manzanaLoyaltyInfoRepeater.maxWidth

                                Component.onCompleted: {
                                    manzanaLoyaltyInfoRepeater.maxWidth = implicitWidth > manzanaLoyaltyInfoRepeater.maxWidth
                                            ? implicitWidth
                                            : manzanaLoyaltyInfoRepeater.maxWidth
                                }
                            }
                            BasicLabel {
                                objectName: "manzanaLoyaltyInfoListElementValue"
                                Style.class: "manzanaLoyaltyInfoLabel"
                                text: modelData.value
                                Layout.fillWidth: true
                            }
                        }
                    }
                }
            }
        }
        // Правая часть
        Item {
            Layout.fillHeight: true
            Layout.preferredWidth: 304
            TopPanel {
                anchors { left: parent.left; top: parent.top; right: parent.right }
                anchors.leftMargin: 24
                hideUserName: true
            }
            ColumnLayout {
                anchors { left: parent.left; right: parent.right; bottom: parent.bottom; margins: 24 }
                spacing: 16
                ColumnLayout {
                    spacing: 24
                    visible: params.canInputBonusForSpend
                    BasicLabel {
                        objectName: "manzanaLoyaltyInfoSpendBonusLabel"
                        Style.class: "manzanaLoyaltyInfoLabel"
                        Tr { code: "manzanaLoyaltyInfoFormSpendBonusLabel"; defaultMessage: "Оплатить бонусами:" }
                    }
                    BasicTextField {
                        id: inputField
                        Style.class: "documentSubtotalInput"
                        padding: 12
                        verticalAlignment: Text.AlignVCenter
                        horizontalAlignment: Text.AlignRight
                        Layout.fillWidth: true
                        Layout.preferredHeight: 64
                        hideCursor: true
                        fixedCursorPosition: true
                        text: operationInfo["AvailablePayment"]
                        validator: RegularExpressionValidator { regularExpression: /^([1-9]\d{0,8}|0)([.]\d{0,2})?$/ }
                    }
                    InlineKeyboard {
                        objectName: "manzanaLoyaltyInfoKeyboard"
                        Layout.fillWidth: true
                        Layout.preferredHeight: 296
                        layoutType: "digits"
                    }
                }
                ColumnLayout {
                    spacing: 8
                    BasicButton {
                        objectName: "manzanaLoyaltyInfoBackButton"
                        Style.class: "manzanaLoyaltyInfoBack"
                        Layout.fillWidth: true
                        Layout.preferredHeight: 68
                        Tr { code: "manzanaLoyaltyInfoFormBackButton"; defaultMessage: "Назад" }
                        onClicked: eventFilter.cancel()
                    }
                    BasicButton {
                        objectName: "manzanaLoyaltyInfoNextButton"
                        Style.class: "manzanaLoyaltyInfoNext"
                        Layout.fillWidth: true
                        Layout.preferredHeight: 68
                        iconLayout.alignment: Qt.AlignTop | Qt.AlignRight
                        Tr { code: "manzanaLoyaltyInfoFormNextButton"; defaultMessage: "Далее" }
                        icon: Style.parameter("icon.actionPanel.arrow")
                        onClicked: eventFilter.ok()
                    }
                }
            }
        }
    }

    Manzana2019Handler { id: handler; canInputBonusForSpend: params.canInputBonusForSpend }

    Component.onCompleted: {
        inputField.selectAll()
    }
}
