import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtWebEngine

import "components"
import "view"

import Artix.Handlers
import Artix.Core
import Artix.Gui

/**
 * @brief Форма web-браузера
 */
FullscreenDialog {
    id: root
    scale: 1
    implicitHeight: primaryScreen.geometry.height - mainWindow.footer.height * mainWindow.scaleFactor
    property BrowserEventFilter eventFilter: BrowserEventFilter {
        blockAllKeyEvents: false
        onExit: handler.emitAction("DIALOG_WEB_BROWSER")
    }

    header: Item {
        height: 72 * mainWindow.scaleFactor
        Item {
            anchors { top: parent.top; bottom: parent.bottom; left: parent.left }
            width: parent.width - webBrowserTopPanel.offset - topPanel.iconsWidth * mainWindow.scaleFactor
            RowLayout {
                id: webBrowserTopPanel
                objectName: "webBrowserTopPanel"
                property int offset: 16 * mainWindow.scaleFactor
                x: offset + width * (mainWindow.scaleFactor - 1) / 2;
                y: height * (mainWindow.scaleFactor - 1) / 2;
                width: (parent.width - offset) / mainWindow.scaleFactor;
                height: parent.height / mainWindow.scaleFactor;
                spacing: 24
                scale: mainWindow.scaleFactor
                // Закрытие диалога
                BasicButton {
                    objectName: "webBrowserExitButton"
                    Style.class: "webBrowserExit"
                    Layout.preferredWidth: 56; Layout.preferredHeight: 56; radius: 28
                    Layout.alignment: Qt.AlignVCenter
                    icon: Style.parameter("icon.browser.exit")
                    onClicked: handler.emitAction("DIALOG_WEB_BROWSER")
                }
                // Перейти на предыдущую страницу
                BasicButton {
                    objectName: "webBrowserBackButton"
                    Style.class: "webBrowserCommon"
                    Layout.preferredWidth: 56; Layout.preferredHeight: 56; radius: 28
                    Layout.alignment: Qt.AlignVCenter
                    enabled: webView.canGoBack
                    icon: webView.canGoBack ? Style.parameter("icon.browser.back")
                                            : Style.parameter("icon.browser.backDisabled")
                    onClicked: webView.goBack()
                }
                // Перейти на следующую страницу
                BasicButton {
                    objectName: "webBrowserForwardButton"
                    Style.class: "webBrowserCommon"
                    Layout.preferredWidth: 56; Layout.preferredHeight: 56; radius: 28
                    Layout.alignment: Qt.AlignVCenter
                    enabled: webView.canGoForward
                    icon: webView.canGoForward ? Style.parameter("icon.browser.forward")
                                               : Style.parameter("icon.browser.forwardDisabled")
                    onClicked: webView.goForward()
                }
                // Обновить страницу или остановить загрузку страницы
                BasicButton {
                    objectName: "webBrowserReloadButton"
                    Style.class: "webBrowserCommon"
                    Layout.preferredWidth: 56; Layout.preferredHeight: 56; radius: 28
                    Layout.alignment: Qt.AlignVCenter
                    icon: webView.loading ? Style.parameter("icon.browser.stop")
                                          : Style.parameter("icon.browser.reload")
                    onClicked: {
                        if (webView.loading)
                            webView.stop()
                        else
                            webView.reload()
                    }
                }
                // Заголовок страницы
                BasicLabel {
                    objectName: "webBrowserTitleLabel"
                    Style.class: "webBrowserTitle"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 24
                    Layout.alignment: Qt.AlignVCenter
                    text: webView.title
                    elide: Label.ElideRight
                }
            }
        }
        TopPanel {
            id: topPanel
            objectName: "artixTopPanel"
            anchors { top: parent.top; bottom: parent.bottom; right: parent.right }
            scale: mainWindow.scaleFactor
            hideUserName: true
        }
        // Прогресс загрузки страницы
        ProgressBar {
            objectName: "webBrowserProgressBar"
            anchors.top: parent.bottom
            width: parent.width; height: 2
            to: 100
            value: webView.loadProgress
            visible: webView.loading
            contentItem: Item {
                property real progressWidth: width * parent.visualPosition
                Rectangle {
                    x: 0; y: 0
                    width: parent.progressWidth; height: parent.height
                    color: Style.parameter("color.blueDark")
                }
            }
            background: null
        }
    }

    contentItem: WebEngineView {
        id: webView
        objectName: "webBrowserWebView"
        url: params.url
        settings.defaultTextEncoding: params.codePage
    }

    DialogHandler { id: handler }

    // Всплывающая клавиатура
    PopupKeyboard {
        id: popupKeyboard
        objectName: "webBrowserPopupKeyboard"
        keyboard {
            layoutType: params.showDigitalKeyboard ? "input_digits" : "main"
            onEnter: handler.emitKey(Qt.Key_Enter)
        }
        Connections {
            target: Qt.inputMethod
            function onVisibleChanged() {
                if (!params.showKeyboard)
                    return

                if (Qt.inputMethod.visible)
                    popupKeyboard.open()
                else
                    popupKeyboard.close()
            }
        }
    }

    LockDelay { enabled: params.lockDelay }
}
