import QtQuick
import QtQuick.Layouts

import "../components"

import Artix.Core
import Artix.Gui

/**
 * @brief Шапка списка позиций
 */
GroupBox {
    ProxyDocument { id: document }
    readonly property bool backMode: Session.document.type === DocumentType.BackBySale || Session.document.type === DocumentType.Back

    Layout.fillWidth: true
    Layout.preferredHeight: 56
    property int positionsCount: 0
    padding: 24
    leftPadding: 16
    rightPadding: 16
    contentItem: RowLayout {
        spacing: 0
        BasicLabel {
            visible: !Config.getLogical("plugins:pricecore", false)
            Style.class: backMode ? "positionsListBackHeader" : "positionsListHeader"
            Tr { tr: document.name; args: [ Session.document.num ] }
        }
        BasicLabel {
            visible: Config.getLogical("plugins:pricecore", false) && Session.document.hasCard
            Style.class: "positionsListHeaderCustomer"
            Layout.preferredWidth: 125
            maximumLineCount: 1
            elide: Text.ElideRight
            text: Session.document?.firstActiveCard?.card?.client ? Session.document.firstActiveCard.card.client.name : ""
        }
        Item { Layout.preferredWidth: 8 }
        BasicLabel {
            id: invoiceLabel
            visible: Config.getLogical("plugins:pricecore", false) && Session.document.hasCard
            Style.class: "positionsListHeaderInvoice"
            Layout.preferredWidth: 170
            maximumLineCount: 1
            elide: Text.ElideRight
            property string invoice: Session.document?.pluginData?.pricecore?.hasOwnProperty("invoiceID")
                                     ? Session.document.pluginData.pricecore.invoiceID : ""
            Tr { code: "positionsListHeaderInvoice"; defaultMessage: "Инвойс %1"; args: [ invoiceLabel.invoice ] }
        }
        Item { Layout.preferredWidth: 16 }
        Image {
            fillMode: Image.PreserveAspectFit
            source: backMode ? Style.parameter("icon.positionsHeader.cartRed") : Style.parameter("icon.positionsHeader.cart")
            Layout.preferredHeight: 16
            Layout.preferredWidth: 16
            Component.onCompleted: mainWindow.scaleImage(this)
        }
        Item { Layout.preferredWidth: 4 }
        BasicLabel {
            Style.class: backMode ? "positionsListBackHeader" : "positionsListHeader"
            text: positionsCount
        }
        Item { Layout.fillWidth: true }
        Image {
            Layout.preferredHeight: 16
            Layout.preferredWidth: 16
            source: backMode ? Style.parameter("icon.positionsHeader.cardRed") : Style.parameter("icon.positionsHeader.card")
            visible: Session.document.hasCard
            Component.onCompleted: mainWindow.scaleImage(this)
        }
        Item { Layout.preferredWidth: 12; visible: Session.document.hasCoupon && Session.document.hasCard }
        Image {
            Layout.preferredHeight: 16
            Layout.preferredWidth: 16
            source: backMode ? Style.parameter("icon.positionsHeader.couponRed") : Style.parameter("icon.positionsHeader.coupon")
            visible: Session.document.hasCoupon
            Component.onCompleted: mainWindow.scaleImage(this)
        }
        Item { Layout.preferredWidth: 4; visible: Session.document.hasCoupon }
        BasicLabel {
            Style.class: backMode ? "positionsListBackHeader" : "positionsListHeader"
            text: "x" + Session.document.coupons.length
            visible: Session.document.coupons.length > 1
        }
    }
    Line {
        y: parent.height - 1
        width: parent.width
        strokeWidth: 1
        color: Style.parameter("color.grayMedium")
    }
}
