import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../../components"
import "../"

import Artix.Core
import Artix.Gui

/**
 * @brief Панель оплаты
 */
ColumnLayout {
    id: root
    spacing: 16

    signal back()
    signal commit(var action, var args)
    property var action
    readonly property BasicTextField inputField: inputField

    // Поле ввода
    BasicTextField {
        id: inputField

        Layout.fillWidth: true
        Layout.preferredHeight: 64
        Style.class: "documentSubtotalInput"
        padding: 12
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignRight
        hideCursor: true
        fixedCursorPosition: true
        placeholder { visible: true }

        property var regexp: /^(\d{0,9})([.]\d{0,2})?$/
        property string lastValidatedInput: ""

        onTextChanged: {
            let trimmedText = text.replace(/\s/g, "")
            if (!regexp.test(trimmedText)) {
                text = lastValidatedInput
                return
            }
            let parts = trimmedText.split(".")
            let tempText = Utils.formatMoneyItem(parts[0]).replace(".00", "")
            if (parts.length > 1)
                tempText = tempText + "." + parts[1]
            text = tempText
            lastValidatedInput = text
        }
    }
    Item {
        Layout.fillHeight: true
    }
    // Клавиатура и панель действий
    Item {
        Layout.fillWidth: true
        Layout.preferredHeight: 303 + (Style.resolution.height - 768) * (0.166 * actions.rows)
        GridLayout {
            id: actions
            anchors.fill: parent
            rowSpacing: 8
            columnSpacing: 8
            columns: 2
            rows: 4

            readonly property real cellWidth: (parent.width - columnSpacing * (columns - 1)) / columns // Ширина кнопки
            readonly property real cellHeight: (parent.height - rowSpacing * (rows - 1)) / rows        // Высота кнопки

            BasicButton {
                Style.class: "actionPanelDelegate24px600"
                Layout.preferredWidth: actions.cellWidth
                Layout.preferredHeight: actions.cellHeight * Layout.rowSpan + actions.rowSpacing * (Layout.rowSpan - 1)
                Layout.row: 0
                Layout.rowSpan: 2
                Layout.column: 1

                textLayout {
                    fillWidth: true
                    fillHeight: true
                }
                iconLayout {
                    alignment: Qt.AlignRight | Qt.AlignTop
                    preferredWidth: 32
                    preferredHeight: 32
                }
                verticalAlignment: Text.AlignBottom
                Tr { code: "actionPanelButtonBack"; defaultMessage: "Назад" }
                onClicked: root.back()
            }
            BasicButton {
                Style.class: "actionPanelDelegateContinue"
                Layout.preferredWidth: actions.cellWidth
                Layout.preferredHeight: actions.cellHeight * Layout.rowSpan + actions.rowSpacing * (Layout.rowSpan - 1)
                Layout.row: 2
                Layout.rowSpan: 2
                Layout.column: 1

                textLayout {
                    fillWidth: true
                    fillHeight: true
                }
                iconLayout {
                    alignment: Qt.AlignRight | Qt.AlignTop
                    preferredWidth: 32
                    preferredHeight: 32
                }
                verticalAlignment: Text.AlignBottom
                icon: Style.parameter("icon.actionPanel.arrow")
                Tr { code: "actionPanelButtonAdd"; defaultMessage: "Добавить" }
                onClicked: {
                    let args = {}
                    if (inputField.text.length > 0)
                        args["amount"] = inputField.text.replace(/\s/g, "")
                    root.commit(root.action, args)
                }
            }
            InlineKeyboard {
                Style.class: "actionPanelDelegate"
                Layout.fillHeight: true
                Layout.preferredWidth: actions.cellWidth
                Layout.row: 0
                Layout.rowSpan: 4
                Layout.column: 0
                layoutType: "digits"
            }
        }
    }
}
